@@ -1377,7 +1377,6 @@ gth_main_activate_extensions (void)
 		"desktop_background",
 		"edit_metadata",
 		"exiv2_tools",
-		"facebook",
 		"file_manager",
 		"find_duplicates",
 		"flicker",
@@ -1390,7 +1389,6 @@ gth_main_activate_extensions (void)
 		"list_tools",
 		"oauth",
 		"photo_importer",
-		"picasaweb",
 		"raw_files",
 		"red_eye_removal",
 		"rename_series",
